@@ -26,6 +26,9 @@ class Client:
         self.__leaf_session_token = credentials["leaf_session_token"]
         self.__status = "unauthenticated"
 
+        self.__performance_analyser_username = credentials["performance_analyser_username"]
+        self.__performance_analyser_password = credentials["performance_analyser_password"]
+
         self.__api_host = host
         # Verify SSL certs
         self.__verify = True
@@ -95,6 +98,8 @@ class Client:
             authenticate_data = resp.json()["data"]
             try:
                 self.__status = "authenticated"
+                self.__tree_id = authenticate_data["tree_id"]
+                self.__branch_id = authenticate_data["branch_id"]
                 self.rabbit_credentials["tree_id"] = authenticate_data["tree_id"]
                 self.rabbit_credentials["branch_id"] = authenticate_data["branch_id"]
                 consumer = Consumer(self.rabbit_credentials,
@@ -182,6 +187,32 @@ class Client:
                 self.__leaf_name, "leaf not authenticated")
             raise Exception(msg)
 
+    def send_performance_metrics(self, aggregation_id: str, data: str):
+        try:
+            url = self.__api_host + "/v1/performance/analysis"
+            headers = {"accept": "application/json"}
+            data = json.dumps({"aggregation_id": aggregation_id,
+                               "leaf_id": self.__leaf_id,
+                               "branch_id": self.__branch_id,
+                               "tree_id": self.__tree_id,
+                               "data": data})
+
+            resp = requests.get(url, headers=headers, data=data,
+                                auth=(self.__performance_analyser_username, self.__performance_analyser_password), verify=self.__verify)
+
+            print(
+                f"received resp code form performance_analyser: {resp.status_code}")
+            if resp.status_code != HTTPStatus.CREATED:
+                raise Exception(resp.json())
+            else:
+                return True
+
+        except Exception as e:
+            msg = "Sending Performance Metrics failed for aggregation {}: {}".format(
+                aggregation_id, e)
+            logging.error(msg)
+            return False
+
     @property
     def leaf_id(self):
         return self.__leaf_id
